@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -265,6 +265,7 @@ class DeploymentCache:
 
     def _get_action_state(self, action):
         import itertools
+        from q2cli.core.usage import cache_examples
 
         state = {
             'id': action.id,
@@ -272,6 +273,7 @@ class DeploymentCache:
             'description': action.description,
             'signature': [],
             'deprecated': action.deprecated,
+            'examples': cache_examples(action)
         }
 
         sig = action.signature
